#
# spec file for package cinnamon-screensaver
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           cinnamon-screensaver
Version:        3.2.13
Release:        1.1
Summary:        Cinnamon screensaver and locker
License:        GPL-2.0+
Group:          System/GUI/Other
Url:            https://github.com/linuxmint/cinnamon-screensaver
Source:         https://github.com/linuxmint/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE cinnamon-screensaver-suse-pam.patch -- Use SUSE-specific PAM configuration.
Patch0:         %{name}-suse-pam.patch
# PATCH-FIX-OPENSUSE cinnamon-screensaver-xscreensaver-path.patch boo#960165 sor.alexei@meowr.ru -- Correct xscreensaver hacks path.
Patch1:         %{name}-xscreensaver-path.patch
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  python3 >= 3.4
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gdk-x11-3.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
Requires:       iso-country-flags-png
Requires:       libcinnamon-desktop-data
Requires:       python3-cairo
Requires:       python3-gobject
Requires:       python3-gobject-cairo
Requires:       python3-setproctitle
Recommends:     cinnamon-translations
Recommends:     xscreensaver-data
Suggests:       xscreensaver-data-extra
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
Requires:       python3-gobject-Gdk
%endif
%if 0%{?suse_version} > 1320 || (0%{?sle_version} >= 120200 && 0%{?is_opensuse})
Requires:       python3-xlib
%endif

%description
cinnamon-screensaver is a screensaver and locker that aims to have
simple, sane and secure defaults, and be well integrated with the
Cinnamon Desktop.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
  --disable-static          \
  --disable-schemas-compile
make %{?_smp_mflags} V=1

%install
%make_install

# Remove development files as they're not really there to be used.
rm -rf %{buildroot}%{_libdir}/libcscreensaver.so \
  %{buildroot}%{_includedir}/%{name}/                  \
  %{buildroot}%{_libdir}/pkgconfig/cscreensaver.pc     \
  %{buildroot}%{_datadir}/gir-1.0/CScreensaver-1.0.gir

find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}%{_datadir}/
%suse_update_desktop_file %{name}

%post
/sbin/ldconfig
%desktop_database_post
%icon_theme_cache_post

%postun
/sbin/ldconfig
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc AUTHORS COPYING* README debian/changelog
%config %{_sysconfdir}/pam.d/cinnamon-screensaver
%{_bindir}/%{name}
%{_bindir}/%{name}-command
%{_libexecdir}/%{name}-pam-helper
%{_datadir}/%{name}/
%{_libdir}/libcscreensaver.so*
%{_libdir}/girepository-1.0/CScreensaver-1.0.typelib
%{_datadir}/dbus-1/services/org.cinnamon.ScreenSaver.service
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/*/screensaver-*.*

%changelog
* Fri Dec 30 2016 sor.alexei@meowr.ru
- Update to version 3.2.13:
  * AuthClient: Check for pam helper in a subdirectory and in
    /usr/libexec/.
  * cinnamon-screensaver-pam-helper.c: Debug mode - don't print
    message strings, they may contain the password.
  * manager.py: Fix pam helper cancellation in Debian Jessie.
    There is an existing workaround for Debian Jessie that skips
    the fade-out when unlocking, due to another issue.
    This causes our despawn_stage callback to be called immediately,
    which sets self.stage to None, before cancel_unlocking can be
    run.
  * keybindings.py: Don't allow the keyboard popup menu key to slip
    through.
  * stage: Clear the clipboard if we're locked (should be
    inaccessible anyhow but…).
  * Add some tooltips to a few ui elements.
  * stage.py: Fix logic surrounding hiding/showing the floating
    widgets when power states change, or when a plugin is unable to
    run due to the power state.
* Fri Dec 23 2016 sor.alexei@meowr.ru
- Update to version 3.2.12 (changes since 3.2.9):
  * cinnamon-screensaver-pam-helper: Add a sleep() to the stdin
    wait loop, make sure the helper is killed whenever the
    screensaver is deactivated.
  * manager.py: Only try to cancel_unlocking if there is a stage.
  * Move the pam-helper binary to libexecdir.
- Remove cinnamon-screensaver-fix-pamhelper-path.patch: fixed
  upstream.
* Thu Dec 15 2016 sor.alexei@meowr.ru
- Update to version 3.2.9 (changes since 3.2.6):
  * stage.py: Keep floating widgets centered within their GtkAlign
    region instead of using the padding CSS property - this can
    only ever work by taking monitor size into account.
  * stage.py: The unlock dialogue can take up more than 1/3 the
    width of the screen, so account for its width when positioning
    floating widgets during Awake state.
  * Add missing -lXext
  * Volume control: Don't crash when PA returns no default sink.
  * stage.py: Regrab the stage if grab is broken (notably by
    fingerprint-helper's gui).
  * Fix pam authentication to work with multi-factor, fingerprint, etc.
  * floating.py: Increase positioning delay to 30 seconds.
  * audioPanel.py: Don't show panel at all if no players are active.
  * Couple fixes: Show floating widgets immediately upon sleep, add
    a description for AuthClient, send a failure notice when we
    fail.
  * Update pam config for multi-distro compatibility.
  * Add preference to disable floating widgets.
  * clock.py: Make clock preference apply everywhere (like our
    other prefs).
  * cinnamon-screensaver-main.py: use setproctitle to set the
    process name as "cinnamon-screensaver"
  * Add a build option to enable/disable use of setresuid/setresgid
    in the setuid.c file for some distributions. The default
    behaviour remains to not use this.
  * Override the background colour to transparent for various
  'primary' widgets, this reduces (but does not eliminate) the
  tendency to get a 'flash' when the screensaver spawns its window.
  * mediaPlayerWatcher.py: Handle metadata more gracefully - some
    players can return arrays of artist info, some a string -
    handle either.
  * authClient.py: Use a constructor for GBytes creation, ignore a
    message sent prior to the auth client being initialised (user
    hit enter as a means of bringing up the unlock dialogue).
- Rebase cinnamon-screensaver-xscreensaver-path.patch.
- Add cinnamon-screensaver-suse-pam.patch: Use SUSE-specific PAM
  configuration.
- Add cinnamon-screensaver-fix-pamhelper-path.patch: Fix the path
  pamhelper is installed in.
* Fri Nov 25 2016 sor.alexei@meowr.ru
- Update to version 3.2.6 (changes since 3.2.4):
  * Remove the position bar and position labels in infobar.
  * Remove an import on BlinkLabel.
* Thu Nov 24 2016 sor.alexei@meowr.ru
- Update to version 3.2.4:
  * Replace cinnamon-screensaver bin script with
    cinnamon-screensaver.c, to perform setuid checks and fixes
    prior to python and gtk starting.
  * utils.py: Remove liveuser check, it doesn't work as expected.
* Thu Nov 17 2016 sor.alexei@meowr.ru
- Update to version 3.2.3:
  * Declare GdkX11.
  * events: For GTK+ < 3.18, skip the fade out animation, and
    immediately destroy the window. Move the deactivate command
    into an idle callback, so we're not attempting to destroy the
    window while in the middle of processing a motion event.
  * passwordEntry.py: Emulate Gtk.Entry.grab_focus_without_selecting().
    The real call was recently removed, as it doesn't exist in
    Gtk 3.14, however the behaviour is still necessary - tabbing
    between buttons and entry will cause the entire partial
    password to be selected, causing overwrite. This restores the
    original functionality without requiring Gtk 3.18+.
  * Add a Gtk 3.14 fallback stylesheet (it's almost exactly the
    same as Gtk 3.18 currently).
  * Handle clock/albumart padding in the GtkOverlay position code -
    it seems not to include this in its preferred-size calculations.
  * Invert the scroll direction for the volume slider.
  * panels: Remove separators. Tweak spacing for keyboard layout
    icon in the Gtk 3.18 CSS file.
  * utils.py: Clean up get_user_name() calls.
  * Disable locking if pam files aren't found or if we're running
    as root.
  * utils.py: Add 'liveuser' group check to user_can_lock()
    function.
* Sun Nov 13 2016 sor.alexei@meowr.ru
- Update to version 3.2.2 (changes since 3.2.0):
  * Layout/l10n: Fix minor visual issues.
  * unlock/accountsServiceClient: Don't cache the username and face
    path, instead fetch them from AccountsService when used.
    Also, allow for no face image by not using a fallback generic
    image, and hiding the image widget if there is no face for it.
  * Remove some Gtk 3.18+ api calls - with a small change to
    GdkScreen updating, the stacking order is correct at stage
    construction and never changes.
  * ConsoleKit: Add lock/unlock signal.
* Tue Nov  8 2016 sor.alexei@meowr.ru
- Update to version 3.2.0:
  * Migrate away from gnome-common deprecated vars and macros.
  * Rewrite on Python.
  * Use XAppKbdLayoutController to interact with libgnomekbd for
    switching keyboard layouts and getting reliable flag icons.
- Rebase cinnamon-screensaver-xscreensaver-path.patch.
- Remove cinnamon-screensaver.pam: nothing needs it anymore.
* Wed Jun  1 2016 sor.alexei@meowr.ru
- Update to version 3.0.1:
  * gs-lock-plug: Remove the hardcoded text colours.
  * Fix unlock dialog display in hidpi.
  * gs-window-x11.c: Fix a couple of compiler warnings.
  * gs-lock-plug.c: Look at AccountsService for user pic if .face
    is not found. Simplify some of the code – pixbuf loaders have
    built-in file checking.
* Mon Apr 25 2016 sor.alexei@meowr.ru
- Update to version 3.0.0:
  * configure.ac: Drop obsolete macro.
  * configure.ac: Use dots when printing dbus version.
  * Support new libsystemd (which replaces libsystemd-login).
  * Stop trying to make gnome-screensaver* a symlink to
    cinnamon-screensaver*.
* Thu Dec 24 2015 sor.alexei@meowr.ru
- Add cinnamon-screensaver-xscreensaver-path.patch: fix
  xscreensaver hacks path (boo#960165).
- Recommend xscreensaver-data instead of depending.
- Suggest xscreensaver-data-extra.
* Tue Oct 20 2015 sor.alexei@meowr.ru
- Update to 2.8.0:
  * Replace deprecated gdk_cursor_unref() with g_object_unref().
  * Cleanup an unused variable.
  * gs-window-x11.c: Fix random crashing due to accessing invalid
    pointers when cleaning up the GSWindow instance.
  * gs-window-x11.c: Fix trying to control the screensaver socket
    after the plug has been removed (race condition) – by default
    the socket is destroyed when this happens.
  * gs-lock-plug.c: fix runtime warning.
- Correct licence to GPL-2.0+.
* Mon Aug 10 2015 i@marguerite.su
- update version 2.6.4
  * fix segfault due to wrong object being destroyed
* Tue Jun  2 2015 stefan@fam-elser.de
- update to version 2.6.3
* Thu Apr 23 2015 stefan@fam-elser.de
- update to version 2.4.2
* Wed Nov  5 2014 i@marguerite.su
- update version 2.4.0
* Mon Jul 14 2014 i@marguerite.su
- update version 2.3.0
  * Fixed buttons overlapping each others in Russian and
    other languages
  * Wrap away message and don't let it touch the borders
    of its parent box
* Mon May 19 2014 stefan@fam-elser.de
- update version 2.2.3
* Thu May  1 2014 i@marguerite.su
- update version 2.2.1
* Thu Apr 17 2014 i@marguerite.su
- update version 2.2.0
* Sat Oct 26 2013 i@marguerite.su
- copypac from home:cyberorg:cinnamon
- cleanup
- update version 2.0.3
  * Use 12H clock format
* Wed Oct 23 2013 stefan@fam-elser.de
- Updated to version 2.0.2
* Mon Oct 21 2013 stefan@fam-elser.de
- Updated to version 2.0.1
* Fri Oct  4 2013 stefan@fam-elser.de
- Updated to version 2.0.0
